@@ -23,6 +23,6 @@ import sys
 from . import main
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.argv[0] = "lavacli"
     sys.exit(main())
