@@ -102,7 +102,7 @@ def configure_parser(parser, version):
         "-a",
         action="store_true",
         default=False,
-        help="list every devices, inluding retired",
+        help="list every devices, including retired",
     )
     out_format = devices_list.add_mutually_exclusive_group()
     out_format.add_argument(
@@ -280,7 +280,7 @@ def _lookups(value, fields):
         print("list index out of range (%d vs %d)" % (int(key), len(value)))
         return 1
     except KeyError:
-        print("Unknow key '%s' for '%s'" % (key, value))
+        print("Unknown key '%s' for '%s'" % (key, value))
         return 1
     except TypeError:
         print("Unable to lookup inside '%s' for '%s'" % (value, key))
@@ -320,7 +320,7 @@ def handle_dict(proxy, options, _):
                         return 0
                     else:
                         return _lookups(value, options.field.split(".")[1:])
-            print("Unknow field '%s'" % field_name)
+            print("Unknown field '%s'" % field_name)
             return 1
 
     else:
