@@ -28,7 +28,7 @@ from urllib.parse import urlparse
 import xmlrpc.client
 import yaml
 
-from lavacli.utils import loader, print_u, exc2str
+from lavacli.utils import dumper, loader, print_u, exc2str
 
 
 def configure_log_options(parser):
@@ -36,7 +36,7 @@ def configure_log_options(parser):
         "--filters",
         default=None,
         type=str,
-        help="comma seperated list of levels to show",
+        help="comma separated list of levels to show",
     )
     parser.add_argument(
         "--polling",
@@ -201,7 +201,7 @@ def configure_parser(parser, version):
         "--filters",
         default=None,
         type=str,
-        help="comma seperated list of levels to show",
+        help="comma separated list of levels to show",
     )
     jobs_run.add_argument(
         "--no-follow",
@@ -467,7 +467,7 @@ def print_logs(logs, raw, filters):
                     default_flow_style=True,
                     default_style='"',
                     width=10 ** 6,
-                    Dumper=yaml.CDumper,
+                    Dumper=dumper(),
                 )[:-1]
             )
     else:
@@ -485,10 +485,14 @@ def print_logs(logs, raw, filters):
                 msg = str(line["msg"])
             msg = msg.rstrip("\n")
 
+            ns = ""
+            if level == "feedback" and "ns" in line:
+                ns = " <" + COLORS["feedback"] + line["ns"] + COLORS["end"] + ">"
             print_u(
                 COLORS["dt"]
                 + timestamp
                 + COLORS["end"]
+                + ns
                 + " "
                 + COLORS[level]
                 + msg
@@ -514,19 +518,24 @@ def handle_logs(proxy, options, config):
     # Loop
     lines = options.start
     while True:
-        (finished, logs) = _download_logs(
-            proxy, config["version"], options.job_id, lines, options.end
-        )
-        if logs:
-            print_logs(logs, options.raw, options.filters)
-            lines += len(logs)
-        # Loop only if the job is not finished
-        if (
-            finished
-            or options.no_follow
-            or (options.end is not None and lines >= options.end)
-        ):
-            break
+        try:
+            (finished, logs) = _download_logs(
+                proxy, config["version"], options.job_id, lines, options.end
+            )
+            if logs:
+                print_logs(logs, options.raw, options.filters)
+                lines += len(logs)
+            # Loop only if the job is not finished
+            if (
+                finished
+                or options.no_follow
+                or (options.end is not None and lines >= options.end)
+            ):
+                break
+        except xmlrpc.client.ProtocolError as exc:
+            # Ignore temporary Internal Server Error as we already got some logs
+            if lines > options.start and exc.errcode == 500:
+                pass
 
         # Wait some time
         time.sleep(options.polling)
@@ -671,14 +680,14 @@ def handle_show(proxy, options, config):
     job = proxy.scheduler.jobs.show(options.job_id)
 
     if options.output_format == "json":
-        job["submit_time"] = job["submit_time"].value
-        job["start_time"] = job["start_time"].value
-        job["end_time"] = job["end_time"].value
+        job["submit_time"] = job["submit_time"].value if job["submit_time"] else None
+        job["start_time"] = job["start_time"].value if job["start_time"] else None
+        job["end_time"] = job["end_time"].value if job["end_time"] else None
         print(json.dumps(job))
     elif options.output_format == "yaml":
-        job["submit_time"] = job["submit_time"].value
-        job["start_time"] = job["start_time"].value
-        job["end_time"] = job["end_time"].value
+        job["submit_time"] = job["submit_time"].value if job["submit_time"] else None
+        job["start_time"] = job["start_time"].value if job["start_time"] else None
+        job["end_time"] = job["end_time"].value if job["end_time"] else None
         print(yaml.dump(job, default_flow_style=None).rstrip("\n"))
     else:
         print("id          : %s" % job["id"])
