@@ -19,6 +19,7 @@
 
 import argparse
 import jinja2
+from pathlib import Path
 import yaml
 
 from lavacli.utils import loader
@@ -41,7 +42,7 @@ def configure_parser(parser, _):
         "--filters",
         default=None,
         type=str,
-        help="comma seperated list of levels to show",
+        help="comma separated list of levels to show",
     )
     logs_print.add_argument(
         "--raw", default=False, action="store_true", help="print raw logs"
@@ -90,7 +91,9 @@ def handle_templates(_, options):
     # If we give it to argparse, then it's always present even when --path is
     # passed.
     if options.path is None:
-        options.path = ["/etc/lava-server/dispatcher-config/device-types"]
+        options.path = ["/etc/lava-server/dispatcher-config/device-types/"]
+        if Path("/usr/share/lava-server/device-types/").exists():
+            options.path.append("/usr/share/lava-server/device-types/")
 
     env = jinja2.Environment(  # nosec - used to render yaml
         autoescape=False,
@@ -102,7 +105,7 @@ def handle_templates(_, options):
 
     # Build the context
     try:
-        context = {k.split("=")[0]: k.split("=")[1] for k in options.context}
+        context = {k.split("=")[0]: "=".join(k.split("=")[1:]) for k in options.context}
     except Exception:
         print("Invalid context variable")
         print("Should be of the form key=value")
