@@ -62,6 +62,22 @@ def configure_parser(parser, version):
         "config", type=argparse.FileType("r"), help="configuration file"
     )
 
+    if version >= (2020, 4) and version <= (2020, 8):
+        # "certificate"
+        workers_cert = sub.add_parser("certificate", help="worker certificate")
+        cert_sub = workers_cert.add_subparsers(
+            dest="sub_sub_sub_command", help="Sub commands"
+        )
+        cert_sub.required = True
+        cert_get = cert_sub.add_parser("get", help="get the worker certificate")
+        cert_get.add_argument("name", type=str, help="worker name")
+
+        cert_set = cert_sub.add_parser("set", help="set the worker certificate")
+        cert_set.add_argument("name", type=str, help="worker name")
+        cert_set.add_argument(
+            "certificate", type=argparse.FileType("r"), help="certificate file"
+        )
+
     if version >= (2019, 6):
         # "env"
         workers_env = sub.add_parser("env", help="worker environment")
@@ -194,6 +210,19 @@ def handle_config(proxy, options, _):
     return 0
 
 
+def handle_certificate(proxy, options, _):
+    if options.sub_sub_sub_command == "get":
+        env = proxy.scheduler.workers.get_certificate(options.name)
+        print(str(env).rstrip("\n"))
+    else:
+        certificate = options.certificate.read()
+        ret = proxy.scheduler.workers.set_certificate(options.name, certificate)
+        if not ret:
+            print("Unable to store worker certificate")
+            return 1
+    return 0
+
+
 def handle_env(proxy, options, _):
     if options.sub_sub_sub_command == "get":
         env = proxy.scheduler.workers.get_env(options.name)
@@ -273,6 +302,12 @@ def handle_show(proxy, options, config):
 
         if config["version"] >= (2020, 1):
             print("job limit   : %d" % worker["job_limit"])
+
+        if config["version"] >= (2020, 6):
+            print("version     : %s" % worker["version"])
+
+        if "token" in worker:
+            print("token       : %s" % worker["token"])
     return 0
 
 
@@ -296,6 +331,7 @@ def handle(proxy, options, config):
     handlers = {
         "add": handle_add,
         "config": handle_config,
+        "certificate": handle_certificate,
         "env": handle_env,
         "list": handle_list,
         "maintenance": handle_maintenance,
