@@ -24,8 +24,8 @@ import xmlrpc.client
 from lavacli import main
 
 
-def test_aliases_add(setup, monkeypatch, capsys):
-    version = "2018.4"
+def test_aliases_add_before_2019_05(setup, monkeypatch, capsys):
+    version = "2019.04"
     monkeypatch.setattr(sys, "argv", ["lavacli", "aliases", "add", "new_alias"])
     monkeypatch.setattr(
         xmlrpc.client.ServerProxy,
@@ -39,6 +39,27 @@ def test_aliases_add(setup, monkeypatch, capsys):
     assert capsys.readouterr()[0] == ""  # nosec
 
 
+def test_aliases_add(setup, monkeypatch, capsys):
+    version = "2019.05"
+    monkeypatch.setattr(
+        sys, "argv", ["lavacli", "aliases", "add", "new_alias", "device-type"]
+    )
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.aliases.add",
+                "args": ("new_alias", "device-type"),
+                "ret": None,
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert capsys.readouterr()[0] == ""  # nosec
+
+
 def test_aliases_delete(setup, monkeypatch, capsys):
     version = "2018.4"
     monkeypatch.setattr(sys, "argv", ["lavacli", "aliases", "delete", "new_alias"])
@@ -132,8 +153,8 @@ def test_aliases_list_yaml(setup, monkeypatch, capsys):
     assert capsys.readouterr()[0] == "[first-alias, second-alias]\n"  # nosec
 
 
-def test_aliases_show(setup, monkeypatch, capsys):
-    version = "2018.4"
+def test_aliases_show_before_2019_05(setup, monkeypatch, capsys):
+    version = "2019.04"
     monkeypatch.setattr(sys, "argv", ["lavacli", "aliases", "show", "my_alias"])
     monkeypatch.setattr(
         xmlrpc.client.ServerProxy,
@@ -154,8 +175,29 @@ def test_aliases_show(setup, monkeypatch, capsys):
     )
 
 
-def test_aliases_show_json(setup, monkeypatch, capsys):
-    version = "2018.4"
+def test_aliases_show(setup, monkeypatch, capsys):
+    version = "2019.05"
+    monkeypatch.setattr(sys, "argv", ["lavacli", "aliases", "show", "my_alias"])
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.aliases.show",
+                "args": ("my_alias",),
+                "ret": {"name": "my_alias", "device_type": "qemu"},
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert (  # nosec
+        capsys.readouterr()[0] == "name       : my_alias\ndevice-type: qemu\n"
+    )
+
+
+def test_aliases_show_json_before_2019_05(setup, monkeypatch, capsys):
+    version = "2019.04"
     monkeypatch.setattr(
         sys, "argv", ["lavacli", "aliases", "show", "my_alias", "--json"]
     )
@@ -178,8 +220,30 @@ def test_aliases_show_json(setup, monkeypatch, capsys):
     }
 
 
-def test_aliases_show_yaml(setup, monkeypatch, capsys):
+def test_aliases_show_json(setup, monkeypatch, capsys):
     version = "2018.4"
+    monkeypatch.setattr(sys, "argv", ["lavacli", "aliases", "show", "kvm", "--json"])
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.aliases.show",
+                "args": ("kvm",),
+                "ret": {"name": "kvm", "device_type": "qemu"},
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert json.loads(capsys.readouterr()[0]) == {  # nosec
+        "name": "kvm",
+        "device_type": "qemu",
+    }
+
+
+def test_aliases_show_yaml_before_2019_05(setup, monkeypatch, capsys):
+    version = "2019.04"
     monkeypatch.setattr(
         sys, "argv", ["lavacli", "aliases", "show", "my_alias", "--yaml"]
     )
@@ -199,3 +263,24 @@ def test_aliases_show_yaml(setup, monkeypatch, capsys):
     assert (  # nosec
         capsys.readouterr()[0] == "device_types: [qemu, kvm]\nname: my_alias\n"
     )
+
+
+def test_aliases_show_yaml(setup, monkeypatch, capsys):
+    version = "2019.05"
+    monkeypatch.setattr(
+        sys, "argv", ["lavacli", "aliases", "show", "my_alias", "--yaml"]
+    )
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.aliases.show",
+                "args": ("my_alias",),
+                "ret": {"name": "my_alias", "device_type": "qemu"},
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert capsys.readouterr()[0] == "{device_type: qemu, name: my_alias}\n"  # nosec
