@@ -344,7 +344,7 @@ def test_devices_dict_get_render_field_missing(setup, monkeypatch, capsys):
     )
     assert main() == 1  # nosec
     assert (  # nosec
-        capsys.readouterr()[0] == "Unknow key 'worl' for '{'world': 'as usual'}'\n"
+        capsys.readouterr()[0] == "Unknown key 'worl' for '{'world': 'as usual'}'\n"
     )
 
 
@@ -466,7 +466,7 @@ def test_devices_dict_get_jinja2_field_missing(setup, monkeypatch, capsys):
         ],
     )
     assert main() == 1  # nosec
-    assert capsys.readouterr()[0] == "Unknow field 'world'\n"  # nosec
+    assert capsys.readouterr()[0] == "Unknown field 'world'\n"  # nosec
 
 
 def test_devices_dict_set(setup, monkeypatch, capsys, tmpdir):
