@@ -1914,3 +1914,56 @@ def test_jobs_wait(setup, monkeypatch, capsys):
 
     assert main() == 0  # nosec
     assert capsys.readouterr()[0] == "Submitted\nRunning.\n"  # nosec
+
+
+def test_jobs_submit_follow(setup, monkeypatch, capsys, tmpdir):
+    version = "2018.4"
+    with (tmpdir / "job.yaml").open("w") as f_out:
+        f_out.write("job definition as yaml")
+    monkeypatch.setattr(
+        sys, "argv", ["lavacli", "jobs", "submit", "--follow", str(tmpdir / "job.yaml")]
+    )
+    now = xmlrpc.client.DateTime("20180128T01:01:01")
+    monkeypatch.setattr(
+        xmlrpc.client.ServerProxy,
+        "data",
+        [
+            {"request": "system.version", "args": (), "ret": version},
+            {
+                "request": "scheduler.jobs.submit",
+                "args": ("job definition as yaml",),
+                "ret": 5689,
+            },
+            {
+                "request": "scheduler.jobs.logs",
+                "args": ("5689", 0),
+                "ret": (
+                    True,
+                    '- {"dt": "2018-04-23T12:07:02.569264", "lvl": "info", "msg": "lava-dispatcher, installed at version: 2018.4-1"}',
+                ),
+            },
+            {
+                "request": "scheduler.jobs.show",
+                "args": ("5689",),
+                "ret": {
+                    "id": "5689",
+                    "description": "desc",
+                    "device": "qemu01",
+                    "device_type": "qemu",
+                    "health_check": False,
+                    "pipeline": True,
+                    "health": "Complete",
+                    "state": "Finished",
+                    "submitter": "lava-admin",
+                    "submit_time": now,
+                    "start_time": now,
+                    "end_time": now,
+                    "tags": [],
+                    "visibility": "Publicly visible",
+                    "failure_comment": None,
+                },
+            },
+        ],
+    )
+    assert main() == 0  # nosec
+    assert "lava-dispatcher, installed at version: 2018.4" in capsys.readouterr()[0]
